Interface SentClient
-
- All Implemented Interfaces:
public interface SentClientA client for interacting with the Sent REST API synchronously. You can also switch to asynchronous execution via the async method.
This client performs best when you create a single instance and reuse it for all interactions with the REST API. This is because each client holds its own connection pool and thread pools. Reusing connections and threads reduces latency and saves memory. The client also handles rate limiting per client. This means that creating and using multiple instances at the same time will not respect rate limits.
The threads and connections that are held will be released automatically if they remain idle. But if you are writing an application that needs to aggressively release unused resources, then you may call close.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSentClient.WithRawResponseA view of SentClient that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SentClientAsyncasync()Returns a version of this client that uses asynchronous execution. abstract SentClient.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SentClientwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract WebhookServicewebhooks()Configure webhook endpoints for real-time event delivery abstract UserServiceusers()Invite, update, and manage organization users and roles abstract TemplateServicetemplates()Manage message templates with variable substitution abstract ProfileServiceprofiles()Manage organization profiles abstract NumberServicenumbers()Manage and lookup phone numbers abstract MessageServicemessages()Send and track SMS and WhatsApp messages abstract ContactServicecontacts()Create, update, and manage customer contact lists abstract MeServiceme()Retrieve account details abstract Unitclose()Closes this client, relinquishing any underlying resources. -
-
Method Detail
-
async
abstract SentClientAsync async()
Returns a version of this client that uses asynchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
abstract SentClient.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SentClient withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
webhooks
abstract WebhookService webhooks()
Configure webhook endpoints for real-time event delivery
-
users
abstract UserService users()
Invite, update, and manage organization users and roles
-
templates
abstract TemplateService templates()
Manage message templates with variable substitution
-
profiles
abstract ProfileService profiles()
Manage organization profiles
-
numbers
abstract NumberService numbers()
Manage and lookup phone numbers
-
messages
abstract MessageService messages()
Send and track SMS and WhatsApp messages
-
contacts
abstract ContactService contacts()
Create, update, and manage customer contact lists
-
close
abstract Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-