Package dm.sent.client
Interface SentClient.WithRawResponse
-
- All Implemented Interfaces:
public interface SentClient.WithRawResponseA view of SentClient that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract SentClient.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract WebhookService.WithRawResponsewebhooks()Configure webhook endpoints for real-time event delivery abstract UserService.WithRawResponseusers()Invite, update, and manage organization users and roles abstract TemplateService.WithRawResponsetemplates()Manage message templates with variable substitution abstract ProfileService.WithRawResponseprofiles()Manage organization profiles abstract NumberService.WithRawResponsenumbers()Manage and lookup phone numbers abstract MessageService.WithRawResponsemessages()Send and track SMS and WhatsApp messages abstract ContactService.WithRawResponsecontacts()Create, update, and manage customer contact lists abstract MeService.WithRawResponseme()Retrieve account details -
-
Method Detail
-
withOptions
abstract SentClient.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
webhooks
abstract WebhookService.WithRawResponse webhooks()
Configure webhook endpoints for real-time event delivery
-
users
abstract UserService.WithRawResponse users()
Invite, update, and manage organization users and roles
-
templates
abstract TemplateService.WithRawResponse templates()
Manage message templates with variable substitution
-
profiles
abstract ProfileService.WithRawResponse profiles()
Manage organization profiles
-
numbers
abstract NumberService.WithRawResponse numbers()
Manage and lookup phone numbers
-
messages
abstract MessageService.WithRawResponse messages()
Send and track SMS and WhatsApp messages
-
contacts
abstract ContactService.WithRawResponse contacts()
Create, update, and manage customer contact lists
-
me
abstract MeService.WithRawResponse me()
Retrieve account details
-
-
-
-