Package dm.sent.client
Interface SentClientAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface SentClientAsync.WithRawResponseA view of SentClientAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract SentClientAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract WebhookServiceAsync.WithRawResponsewebhooks()Configure webhook endpoints for real-time event delivery abstract UserServiceAsync.WithRawResponseusers()Invite, update, and manage organization users and roles abstract TemplateServiceAsync.WithRawResponsetemplates()Manage message templates with variable substitution abstract ProfileServiceAsync.WithRawResponseprofiles()Manage organization profiles abstract NumberServiceAsync.WithRawResponsenumbers()Manage and lookup phone numbers abstract MessageServiceAsync.WithRawResponsemessages()Send and track SMS and WhatsApp messages abstract ContactServiceAsync.WithRawResponsecontacts()Create, update, and manage customer contact lists abstract MeServiceAsync.WithRawResponseme()Retrieve account details -
-
Method Detail
-
withOptions
abstract SentClientAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
webhooks
abstract WebhookServiceAsync.WithRawResponse webhooks()
Configure webhook endpoints for real-time event delivery
-
users
abstract UserServiceAsync.WithRawResponse users()
Invite, update, and manage organization users and roles
-
templates
abstract TemplateServiceAsync.WithRawResponse templates()
Manage message templates with variable substitution
-
profiles
abstract ProfileServiceAsync.WithRawResponse profiles()
Manage organization profiles
-
numbers
abstract NumberServiceAsync.WithRawResponse numbers()
Manage and lookup phone numbers
-
messages
abstract MessageServiceAsync.WithRawResponse messages()
Send and track SMS and WhatsApp messages
-
contacts
abstract ContactServiceAsync.WithRawResponse contacts()
Create, update, and manage customer contact lists
-
me
abstract MeServiceAsync.WithRawResponse me()
Retrieve account details
-
-
-
-