Class SentClientAsyncImpl
-
- All Implemented Interfaces:
-
dm.sent.client.SentClientAsync
public final class SentClientAsyncImpl implements SentClientAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSentClientAsyncImpl.WithRawResponseImpl
-
Constructor Summary
Constructors Constructor Description SentClientAsyncImpl(ClientOptions clientOptions)
-
Method Summary
Modifier and Type Method Description SentClientsync()Returns a version of this client that uses synchronous execution. SentClientAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SentClientAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. WebhookServiceAsyncwebhooks()Configure webhook endpoints for real-time event delivery UserServiceAsyncusers()Invite, update, and manage organization users and roles TemplateServiceAsynctemplates()Manage message templates with variable substitution ProfileServiceAsyncprofiles()Manage organization profiles NumberServiceAsyncnumbers()Manage and lookup phone numbers MessageServiceAsyncmessages()Send and track SMS and WhatsApp messages ContactServiceAsynccontacts()Create, update, and manage customer contact lists MeServiceAsyncme()Retrieve account details Unitclose()Closes this client, relinquishing any underlying resources. -
-
Constructor Detail
-
SentClientAsyncImpl
SentClientAsyncImpl(ClientOptions clientOptions)
-
-
Method Detail
-
sync
SentClient sync()
Returns a version of this client that uses synchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
SentClientAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SentClientAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
webhooks
WebhookServiceAsync webhooks()
Configure webhook endpoints for real-time event delivery
-
users
UserServiceAsync users()
Invite, update, and manage organization users and roles
-
templates
TemplateServiceAsync templates()
Manage message templates with variable substitution
-
profiles
ProfileServiceAsync profiles()
Manage organization profiles
-
numbers
NumberServiceAsync numbers()
Manage and lookup phone numbers
-
messages
MessageServiceAsync messages()
Send and track SMS and WhatsApp messages
-
contacts
ContactServiceAsync contacts()
Create, update, and manage customer contact lists
-
me
MeServiceAsync me()
Retrieve account details
-
close
Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-