Package dm.sent.client
Class SentClientAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dm.sent.client.SentClientAsync.WithRawResponse
public final class SentClientAsyncImpl.WithRawResponseImpl implements SentClientAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SentClientAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. WebhookServiceAsync.WithRawResponsewebhooks()Configure webhook endpoints for real-time event delivery UserServiceAsync.WithRawResponseusers()Invite, update, and manage organization users and roles TemplateServiceAsync.WithRawResponsetemplates()Manage message templates with variable substitution ProfileServiceAsync.WithRawResponseprofiles()Manage organization profiles NumberServiceAsync.WithRawResponsenumbers()Manage and lookup phone numbers MessageServiceAsync.WithRawResponsemessages()Send and track SMS and WhatsApp messages ContactServiceAsync.WithRawResponsecontacts()Create, update, and manage customer contact lists MeServiceAsync.WithRawResponseme()Retrieve account details -
-
Method Detail
-
withOptions
SentClientAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
webhooks
WebhookServiceAsync.WithRawResponse webhooks()
Configure webhook endpoints for real-time event delivery
-
users
UserServiceAsync.WithRawResponse users()
Invite, update, and manage organization users and roles
-
templates
TemplateServiceAsync.WithRawResponse templates()
Manage message templates with variable substitution
-
profiles
ProfileServiceAsync.WithRawResponse profiles()
Manage organization profiles
-
numbers
NumberServiceAsync.WithRawResponse numbers()
Manage and lookup phone numbers
-
messages
MessageServiceAsync.WithRawResponse messages()
Send and track SMS and WhatsApp messages
-
contacts
ContactServiceAsync.WithRawResponse contacts()
Create, update, and manage customer contact lists
-
me
MeServiceAsync.WithRawResponse me()
Retrieve account details
-
-
-
-