Class SentClientImpl
-
- All Implemented Interfaces:
-
dm.sent.client.SentClient
public final class SentClientImpl implements SentClient
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSentClientImpl.WithRawResponseImpl
-
Constructor Summary
Constructors Constructor Description SentClientImpl(ClientOptions clientOptions)
-
Method Summary
Modifier and Type Method Description SentClientAsyncasync()Returns a version of this client that uses asynchronous execution. SentClient.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SentClientwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. WebhookServicewebhooks()Configure webhook endpoints for real-time event delivery UserServiceusers()Invite, update, and manage organization users and roles TemplateServicetemplates()Manage message templates with variable substitution ProfileServiceprofiles()Manage organization profiles NumberServicenumbers()Manage and lookup phone numbers MessageServicemessages()Send and track SMS and WhatsApp messages ContactServicecontacts()Create, update, and manage customer contact lists MeServiceme()Retrieve account details Unitclose()Closes this client, relinquishing any underlying resources. -
-
Constructor Detail
-
SentClientImpl
SentClientImpl(ClientOptions clientOptions)
-
-
Method Detail
-
async
SentClientAsync async()
Returns a version of this client that uses asynchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
SentClient.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SentClient withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
webhooks
WebhookService webhooks()
Configure webhook endpoints for real-time event delivery
-
users
UserService users()
Invite, update, and manage organization users and roles
-
templates
TemplateService templates()
Manage message templates with variable substitution
-
profiles
ProfileService profiles()
Manage organization profiles
-
numbers
NumberService numbers()
Manage and lookup phone numbers
-
messages
MessageService messages()
Send and track SMS and WhatsApp messages
-
contacts
ContactService contacts()
Create, update, and manage customer contact lists
-
close
Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-