Package dm.sent.client
Class SentClientImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dm.sent.client.SentClient.WithRawResponse
public final class SentClientImpl.WithRawResponseImpl implements SentClient.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SentClient.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. WebhookService.WithRawResponsewebhooks()Configure webhook endpoints for real-time event delivery UserService.WithRawResponseusers()Invite, update, and manage organization users and roles TemplateService.WithRawResponsetemplates()Manage message templates with variable substitution ProfileService.WithRawResponseprofiles()Manage organization profiles NumberService.WithRawResponsenumbers()Manage and lookup phone numbers MessageService.WithRawResponsemessages()Send and track SMS and WhatsApp messages ContactService.WithRawResponsecontacts()Create, update, and manage customer contact lists MeService.WithRawResponseme()Retrieve account details -
-
Method Detail
-
withOptions
SentClient.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
webhooks
WebhookService.WithRawResponse webhooks()
Configure webhook endpoints for real-time event delivery
-
users
UserService.WithRawResponse users()
Invite, update, and manage organization users and roles
-
templates
TemplateService.WithRawResponse templates()
Manage message templates with variable substitution
-
profiles
ProfileService.WithRawResponse profiles()
Manage organization profiles
-
numbers
NumberService.WithRawResponse numbers()
Manage and lookup phone numbers
-
messages
MessageService.WithRawResponse messages()
Send and track SMS and WhatsApp messages
-
contacts
ContactService.WithRawResponse contacts()
Create, update, and manage customer contact lists
-
me
MeService.WithRawResponse me()
Retrieve account details
-
-
-
-