Package dm.sent.client.okhttp
Class SentOkHttpClient
-
- All Implemented Interfaces:
public final class SentOkHttpClientA class that allows building an instance of SentClient with OkHttpClient as the underlying HttpClient.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSentOkHttpClient.BuilderA builder for SentOkHttpClient.
-
Method Summary
Modifier and Type Method Description final static SentOkHttpClient.Builderbuilder()Returns a mutable builder for constructing an instance of SentClient. final static SentClientfromEnv()Returns a client configured using system properties and environment variables. -
-
Method Detail
-
builder
final static SentOkHttpClient.Builder builder()
Returns a mutable builder for constructing an instance of SentClient.
-
fromEnv
final static SentClient fromEnv()
Returns a client configured using system properties and environment variables.
-
-
-
-