Package dm.sent.client.okhttp
Class SentOkHttpClientAsync
-
- All Implemented Interfaces:
public final class SentOkHttpClientAsyncA class that allows building an instance of SentClientAsync with OkHttpClient as the underlying HttpClient.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSentOkHttpClientAsync.BuilderA builder for SentOkHttpClientAsync.
-
Method Summary
Modifier and Type Method Description final static SentOkHttpClientAsync.Builderbuilder()Returns a mutable builder for constructing an instance of SentClientAsync. final static SentClientAsyncfromEnv()Returns a client configured using system properties and environment variables. -
-
Method Detail
-
builder
final static SentOkHttpClientAsync.Builder builder()
Returns a mutable builder for constructing an instance of SentClientAsync.
-
fromEnv
final static SentClientAsync fromEnv()
Returns a client configured using system properties and environment variables.
-
-
-
-