Class SentOkHttpClientAsync.Builder
-
- All Implemented Interfaces:
public final class SentOkHttpClientAsync.BuilderA builder for SentOkHttpClientAsync.
-
-
Method Summary
Modifier and Type Method Description final SentOkHttpClientAsync.BuilderdispatcherExecutorService(ExecutorService dispatcherExecutorService)The executor service to use for running HTTP requests. final SentOkHttpClientAsync.BuilderdispatcherExecutorService(Optional<ExecutorService> dispatcherExecutorService)Alias for calling Builder.dispatcherExecutorService with dispatcherExecutorService.orElse(null).final SentOkHttpClientAsync.Builderproxy(Proxy proxy)final SentOkHttpClientAsync.Builderproxy(Optional<Proxy> proxy)Alias for calling Builder.proxy with proxy.orElse(null).final SentOkHttpClientAsync.BuilderproxyAuthenticator(ProxyAuthenticator proxyAuthenticator)Provides credentials when an HTTP proxy responds with 407 Proxy Authentication Required.final SentOkHttpClientAsync.BuilderproxyAuthenticator(Optional<ProxyAuthenticator> proxyAuthenticator)Alias for calling Builder.proxyAuthenticator with proxyAuthenticator.orElse(null).final SentOkHttpClientAsync.BuildermaxIdleConnections(Integer maxIdleConnections)The maximum number of idle connections kept by the underlying OkHttp connection pool. final SentOkHttpClientAsync.BuildermaxIdleConnections(Integer maxIdleConnections)Alias for Builder.maxIdleConnections. final SentOkHttpClientAsync.BuildermaxIdleConnections(Optional<Integer> maxIdleConnections)Alias for calling Builder.maxIdleConnections with maxIdleConnections.orElse(null).final SentOkHttpClientAsync.BuilderkeepAliveDuration(Duration keepAliveDuration)The keep-alive duration for idle connections in the underlying OkHttp connection pool. final SentOkHttpClientAsync.BuilderkeepAliveDuration(Optional<Duration> keepAliveDuration)Alias for calling Builder.keepAliveDuration with keepAliveDuration.orElse(null).final SentOkHttpClientAsync.BuildersslSocketFactory(SSLSocketFactory sslSocketFactory)The socket factory used to secure HTTPS connections. final SentOkHttpClientAsync.BuildersslSocketFactory(Optional<SSLSocketFactory> sslSocketFactory)Alias for calling Builder.sslSocketFactory with sslSocketFactory.orElse(null).final SentOkHttpClientAsync.BuildertrustManager(X509TrustManager trustManager)The trust manager used to secure HTTPS connections. final SentOkHttpClientAsync.BuildertrustManager(Optional<X509TrustManager> trustManager)Alias for calling Builder.trustManager with trustManager.orElse(null).final SentOkHttpClientAsync.BuilderhostnameVerifier(HostnameVerifier hostnameVerifier)The verifier used to confirm that response certificates apply to requested hostnames for HTTPS connections. final SentOkHttpClientAsync.BuilderhostnameVerifier(Optional<HostnameVerifier> hostnameVerifier)Alias for calling Builder.hostnameVerifier with hostnameVerifier.orElse(null).final SentOkHttpClientAsync.BuildercheckJacksonVersionCompatibility(Boolean checkJacksonVersionCompatibility)Whether to throw an exception if any of the Jackson versions detected at runtime are incompatible with the SDK's minimum supported Jackson version (2.13.4). final SentOkHttpClientAsync.BuilderjsonMapper(JsonMapper jsonMapper)The Jackson JSON mapper to use for serializing and deserializing JSON. final SentOkHttpClientAsync.Buildersleeper(Sleeper sleeper)The interface to use for delaying execution, like during retries. final SentOkHttpClientAsync.Builderclock(Clock clock)The clock to use for operations that require timing, like retries. final SentOkHttpClientAsync.BuilderbaseUrl(String baseUrl)The base URL to use for every request. final SentOkHttpClientAsync.BuilderbaseUrl(Optional<String> baseUrl)Alias for calling Builder.baseUrl with baseUrl.orElse(null).final SentOkHttpClientAsync.BuilderresponseValidation(Boolean responseValidation)Whether to call validateon every response before returning it.final SentOkHttpClientAsync.Buildertimeout(Timeout timeout)Sets the maximum time allowed for various parts of an HTTP call's lifecycle, excluding retries. final SentOkHttpClientAsync.Buildertimeout(Duration timeout)Sets the maximum time allowed for a complete HTTP call, not including retries. final SentOkHttpClientAsync.BuildermaxRetries(Integer maxRetries)The maximum number of times to retry failed requests, with a short exponential backoff between requests. final SentOkHttpClientAsync.BuilderlogLevel(LogLevel logLevel)The level at which to log request and response information. final SentOkHttpClientAsync.BuilderapiKey(String apiKey)Customer API key for authentication. final SentOkHttpClientAsync.Builderheaders(Headers headers)final SentOkHttpClientAsync.Builderheaders(Map<String, Iterable<String>> headers)final SentOkHttpClientAsync.BuilderputHeader(String name, String value)final SentOkHttpClientAsync.BuilderputHeaders(String name, Iterable<String> values)final SentOkHttpClientAsync.BuilderputAllHeaders(Headers headers)final SentOkHttpClientAsync.BuilderputAllHeaders(Map<String, Iterable<String>> headers)final SentOkHttpClientAsync.BuilderreplaceHeaders(String name, String value)final SentOkHttpClientAsync.BuilderreplaceHeaders(String name, Iterable<String> values)final SentOkHttpClientAsync.BuilderreplaceAllHeaders(Headers headers)final SentOkHttpClientAsync.BuilderreplaceAllHeaders(Map<String, Iterable<String>> headers)final SentOkHttpClientAsync.BuilderremoveHeaders(String name)final SentOkHttpClientAsync.BuilderremoveAllHeaders(Set<String> names)final SentOkHttpClientAsync.BuilderqueryParams(QueryParams queryParams)final SentOkHttpClientAsync.BuilderqueryParams(Map<String, Iterable<String>> queryParams)final SentOkHttpClientAsync.BuilderputQueryParam(String key, String value)final SentOkHttpClientAsync.BuilderputQueryParams(String key, Iterable<String> values)final SentOkHttpClientAsync.BuilderputAllQueryParams(QueryParams queryParams)final SentOkHttpClientAsync.BuilderputAllQueryParams(Map<String, Iterable<String>> queryParams)final SentOkHttpClientAsync.BuilderreplaceQueryParams(String key, String value)final SentOkHttpClientAsync.BuilderreplaceQueryParams(String key, Iterable<String> values)final SentOkHttpClientAsync.BuilderreplaceAllQueryParams(QueryParams queryParams)final SentOkHttpClientAsync.BuilderreplaceAllQueryParams(Map<String, Iterable<String>> queryParams)final SentOkHttpClientAsync.BuilderremoveQueryParams(String key)final SentOkHttpClientAsync.BuilderremoveAllQueryParams(Set<String> keys)final SentOkHttpClientAsync.BuilderfromEnv()Updates configuration using system properties and environment variables. final SentClientAsyncbuild()Returns an immutable instance of SentClientAsync. -
-
Method Detail
-
dispatcherExecutorService
final SentOkHttpClientAsync.Builder dispatcherExecutorService(ExecutorService dispatcherExecutorService)
The executor service to use for running HTTP requests.
Defaults to OkHttp's default executor service.
This class takes ownership of the executor service and shuts it down when closed.
-
dispatcherExecutorService
final SentOkHttpClientAsync.Builder dispatcherExecutorService(Optional<ExecutorService> dispatcherExecutorService)
Alias for calling Builder.dispatcherExecutorService with
dispatcherExecutorService.orElse(null).
-
proxy
final SentOkHttpClientAsync.Builder proxy(Proxy proxy)
-
proxy
final SentOkHttpClientAsync.Builder proxy(Optional<Proxy> proxy)
Alias for calling Builder.proxy with
proxy.orElse(null).
-
proxyAuthenticator
final SentOkHttpClientAsync.Builder proxyAuthenticator(ProxyAuthenticator proxyAuthenticator)
Provides credentials when an HTTP proxy responds with
407 Proxy Authentication Required.
-
proxyAuthenticator
final SentOkHttpClientAsync.Builder proxyAuthenticator(Optional<ProxyAuthenticator> proxyAuthenticator)
Alias for calling Builder.proxyAuthenticator with
proxyAuthenticator.orElse(null).
-
maxIdleConnections
final SentOkHttpClientAsync.Builder maxIdleConnections(Integer maxIdleConnections)
The maximum number of idle connections kept by the underlying OkHttp connection pool.
If this is set, then keepAliveDuration must also be set.
If unset, then OkHttp's default is used.
-
maxIdleConnections
final SentOkHttpClientAsync.Builder maxIdleConnections(Integer maxIdleConnections)
Alias for Builder.maxIdleConnections.
This unboxed primitive overload exists for backwards compatibility.
-
maxIdleConnections
final SentOkHttpClientAsync.Builder maxIdleConnections(Optional<Integer> maxIdleConnections)
Alias for calling Builder.maxIdleConnections with
maxIdleConnections.orElse(null).
-
keepAliveDuration
final SentOkHttpClientAsync.Builder keepAliveDuration(Duration keepAliveDuration)
The keep-alive duration for idle connections in the underlying OkHttp connection pool.
If this is set, then maxIdleConnections must also be set.
If unset, then OkHttp's default is used.
-
keepAliveDuration
final SentOkHttpClientAsync.Builder keepAliveDuration(Optional<Duration> keepAliveDuration)
Alias for calling Builder.keepAliveDuration with
keepAliveDuration.orElse(null).
-
sslSocketFactory
final SentOkHttpClientAsync.Builder sslSocketFactory(SSLSocketFactory sslSocketFactory)
The socket factory used to secure HTTPS connections.
If this is set, then trustManager must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
sslSocketFactory
final SentOkHttpClientAsync.Builder sslSocketFactory(Optional<SSLSocketFactory> sslSocketFactory)
Alias for calling Builder.sslSocketFactory with
sslSocketFactory.orElse(null).
-
trustManager
final SentOkHttpClientAsync.Builder trustManager(X509TrustManager trustManager)
The trust manager used to secure HTTPS connections.
If this is set, then sslSocketFactory must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
trustManager
final SentOkHttpClientAsync.Builder trustManager(Optional<X509TrustManager> trustManager)
Alias for calling Builder.trustManager with
trustManager.orElse(null).
-
hostnameVerifier
final SentOkHttpClientAsync.Builder hostnameVerifier(HostnameVerifier hostnameVerifier)
The verifier used to confirm that response certificates apply to requested hostnames for HTTPS connections.
If unset, then a default hostname verifier is used.
-
hostnameVerifier
final SentOkHttpClientAsync.Builder hostnameVerifier(Optional<HostnameVerifier> hostnameVerifier)
Alias for calling Builder.hostnameVerifier with
hostnameVerifier.orElse(null).
-
checkJacksonVersionCompatibility
final SentOkHttpClientAsync.Builder checkJacksonVersionCompatibility(Boolean checkJacksonVersionCompatibility)
Whether to throw an exception if any of the Jackson versions detected at runtime are incompatible with the SDK's minimum supported Jackson version (2.13.4).
Defaults to true. Use extreme caution when disabling this option. There is no guarantee that the SDK will work correctly when using an incompatible Jackson version.
-
jsonMapper
final SentOkHttpClientAsync.Builder jsonMapper(JsonMapper jsonMapper)
The Jackson JSON mapper to use for serializing and deserializing JSON.
Defaults to dm.sent.core.jsonMapper. The default is usually sufficient and rarely needs to be overridden.
-
sleeper
final SentOkHttpClientAsync.Builder sleeper(Sleeper sleeper)
The interface to use for delaying execution, like during retries.
This is primarily useful for using fake delays in tests.
Defaults to real execution delays.
This class takes ownership of the sleeper and closes it when closed.
-
clock
final SentOkHttpClientAsync.Builder clock(Clock clock)
The clock to use for operations that require timing, like retries.
This is primarily useful for using a fake clock in tests.
Defaults to Clock.systemUTC.
-
baseUrl
final SentOkHttpClientAsync.Builder baseUrl(String baseUrl)
The base URL to use for every request.
Defaults to the production environment:
https://api.sent.dm.
-
baseUrl
final SentOkHttpClientAsync.Builder baseUrl(Optional<String> baseUrl)
Alias for calling Builder.baseUrl with
baseUrl.orElse(null).
-
responseValidation
final SentOkHttpClientAsync.Builder responseValidation(Boolean responseValidation)
Whether to call
validateon every response before returning it.Setting this to
trueis not forwards compatible with new types from the API for existing fields.Defaults to false, which means the shape of the response will not be validated upfront. Instead, validation will only occur for the parts of the response that are accessed.
-
timeout
final SentOkHttpClientAsync.Builder timeout(Timeout timeout)
Sets the maximum time allowed for various parts of an HTTP call's lifecycle, excluding retries.
Defaults to Timeout.default.
-
timeout
final SentOkHttpClientAsync.Builder timeout(Duration timeout)
Sets the maximum time allowed for a complete HTTP call, not including retries.
See Timeout.request for more details.
For fine-grained control, pass a Timeout object.
-
maxRetries
final SentOkHttpClientAsync.Builder maxRetries(Integer maxRetries)
The maximum number of times to retry failed requests, with a short exponential backoff between requests.
Only the following error types are retried:
Connection errors (for example, due to a network connectivity problem)
408 Request Timeout
409 Conflict
429 Rate Limit
5xx Internal
The API may also explicitly instruct the SDK to retry or not retry a request.
Defaults to 2.
-
logLevel
final SentOkHttpClientAsync.Builder logLevel(LogLevel logLevel)
The level at which to log request and response information.
fromEnv will set the level from environment variables. See LogLevel.fromEnv.
Defaults to LogLevel.fromEnv.
-
apiKey
final SentOkHttpClientAsync.Builder apiKey(String apiKey)
Customer API key for authentication. Use
sk_live_*keys for production andsk_test_*keys for sandbox/testing. Pass via thex-api-keyheader.
-
headers
final SentOkHttpClientAsync.Builder headers(Headers headers)
-
putHeader
final SentOkHttpClientAsync.Builder putHeader(String name, String value)
-
putHeaders
final SentOkHttpClientAsync.Builder putHeaders(String name, Iterable<String> values)
-
putAllHeaders
final SentOkHttpClientAsync.Builder putAllHeaders(Headers headers)
-
putAllHeaders
final SentOkHttpClientAsync.Builder putAllHeaders(Map<String, Iterable<String>> headers)
-
replaceHeaders
final SentOkHttpClientAsync.Builder replaceHeaders(String name, String value)
-
replaceHeaders
final SentOkHttpClientAsync.Builder replaceHeaders(String name, Iterable<String> values)
-
replaceAllHeaders
final SentOkHttpClientAsync.Builder replaceAllHeaders(Headers headers)
-
replaceAllHeaders
final SentOkHttpClientAsync.Builder replaceAllHeaders(Map<String, Iterable<String>> headers)
-
removeHeaders
final SentOkHttpClientAsync.Builder removeHeaders(String name)
-
removeAllHeaders
final SentOkHttpClientAsync.Builder removeAllHeaders(Set<String> names)
-
queryParams
final SentOkHttpClientAsync.Builder queryParams(QueryParams queryParams)
-
queryParams
final SentOkHttpClientAsync.Builder queryParams(Map<String, Iterable<String>> queryParams)
-
putQueryParam
final SentOkHttpClientAsync.Builder putQueryParam(String key, String value)
-
putQueryParams
final SentOkHttpClientAsync.Builder putQueryParams(String key, Iterable<String> values)
-
putAllQueryParams
final SentOkHttpClientAsync.Builder putAllQueryParams(QueryParams queryParams)
-
putAllQueryParams
final SentOkHttpClientAsync.Builder putAllQueryParams(Map<String, Iterable<String>> queryParams)
-
replaceQueryParams
final SentOkHttpClientAsync.Builder replaceQueryParams(String key, String value)
-
replaceQueryParams
final SentOkHttpClientAsync.Builder replaceQueryParams(String key, Iterable<String> values)
-
replaceAllQueryParams
final SentOkHttpClientAsync.Builder replaceAllQueryParams(QueryParams queryParams)
-
replaceAllQueryParams
final SentOkHttpClientAsync.Builder replaceAllQueryParams(Map<String, Iterable<String>> queryParams)
-
removeQueryParams
final SentOkHttpClientAsync.Builder removeQueryParams(String key)
-
removeAllQueryParams
final SentOkHttpClientAsync.Builder removeAllQueryParams(Set<String> keys)
-
fromEnv
final SentOkHttpClientAsync.Builder fromEnv()
Updates configuration using system properties and environment variables.
-
build
final SentClientAsync build()
Returns an immutable instance of SentClientAsync.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-