Class UserUpdateRoleResponse
-
- All Implemented Interfaces:
public final class UserUpdateRoleResponseStandard API response envelope for all v3 endpoints
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUserUpdateRoleResponse.BuilderA builder for UserUpdateRoleResponse.
public final classUserUpdateRoleResponse.DataUser response for v3 API
public final classUserUpdateRoleResponse.ErrorError information
public final classUserUpdateRoleResponse.MetaRequest and response metadata
-
Method Summary
Modifier and Type Method Description final Optional<UserUpdateRoleResponse.Data>data()User response for v3 API final Optional<UserUpdateRoleResponse.Error>error()Error information final Optional<UserUpdateRoleResponse.Meta>meta()Request and response metadata final Optional<Boolean>success()Indicates whether the request was successful final JsonField<UserUpdateRoleResponse.Data>_data()Returns the raw JSON value of data. final JsonField<UserUpdateRoleResponse.Error>_error()Returns the raw JSON value of error. final JsonField<UserUpdateRoleResponse.Meta>_meta()Returns the raw JSON value of meta. final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final UserUpdateRoleResponse.BuildertoBuilder()final UserUpdateRoleResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UserUpdateRoleResponse.Builderbuilder()Returns a mutable builder for constructing an instance of UserUpdateRoleResponse. -
-
Method Detail
-
data
final Optional<UserUpdateRoleResponse.Data> data()
User response for v3 API
-
error
final Optional<UserUpdateRoleResponse.Error> error()
Error information
-
meta
final Optional<UserUpdateRoleResponse.Meta> meta()
Request and response metadata
-
_data
final JsonField<UserUpdateRoleResponse.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_error
final JsonField<UserUpdateRoleResponse.Error> _error()
Returns the raw JSON value of error.
Unlike error, this method doesn't throw if the JSON field has an unexpected type.
-
_meta
final JsonField<UserUpdateRoleResponse.Meta> _meta()
Returns the raw JSON value of meta.
Unlike meta, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UserUpdateRoleResponse.Builder toBuilder()
-
validate
final UserUpdateRoleResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UserUpdateRoleResponse.Builder builder()
Returns a mutable builder for constructing an instance of UserUpdateRoleResponse.
-
-
-
-