Class UserUpdateRoleResponse.Data
-
- All Implemented Interfaces:
public final class UserUpdateRoleResponse.DataUser response for v3 API
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUserUpdateRoleResponse.Data.BuilderA builder for Data.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()User unique identifier final Optional<OffsetDateTime>createdAt()When the user was added to the organization final Optional<String>email()User email address final Optional<OffsetDateTime>invitedAt()When the user was invited final Optional<OffsetDateTime>lastLoginAt()When the user last logged in final Optional<String>name()User full name final Optional<String>role()User role in the organization: admin, billing, developer final Optional<String>status()User status: active, invited, suspended, rejected final Optional<OffsetDateTime>updatedAt()When the user record was last updated final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<OffsetDateTime>_invitedAt()Returns the raw JSON value of invitedAt. final JsonField<OffsetDateTime>_lastLoginAt()Returns the raw JSON value of lastLoginAt. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_role()Returns the raw JSON value of role. final JsonField<String>_status()Returns the raw JSON value of status. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final UserUpdateRoleResponse.Data.BuildertoBuilder()final UserUpdateRoleResponse.Datavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UserUpdateRoleResponse.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
When the user was added to the organization
-
invitedAt
final Optional<OffsetDateTime> invitedAt()
When the user was invited
-
lastLoginAt
final Optional<OffsetDateTime> lastLoginAt()
When the user last logged in
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
When the user record was last updated
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_invitedAt
final JsonField<OffsetDateTime> _invitedAt()
Returns the raw JSON value of invitedAt.
Unlike invitedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_lastLoginAt
final JsonField<OffsetDateTime> _lastLoginAt()
Returns the raw JSON value of lastLoginAt.
Unlike lastLoginAt, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_role
final JsonField<String> _role()
Returns the raw JSON value of role.
Unlike role, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UserUpdateRoleResponse.Data.Builder toBuilder()
-
validate
final UserUpdateRoleResponse.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UserUpdateRoleResponse.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
-
-
-
-