Class WebhookCreateParams
-
- All Implemented Interfaces:
-
dm.sent.core.Params
public final class WebhookCreateParams implements Params
Creates a new webhook endpoint for the authenticated customer.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookCreateParams.BuilderA builder for WebhookCreateParams.
public final classWebhookCreateParams.Bodypublic final classWebhookCreateParams.EventFilters
-
Method Summary
Modifier and Type Method Description final Optional<String>idempotencyKey()final Optional<String>xProfileId()final Optional<Boolean>sandbox()Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution final Optional<String>displayName()final Optional<String>endpointUrl()final Optional<WebhookCreateParams.EventFilters>eventFilters()final Optional<List<String>>eventTypes()final Optional<Integer>retryCount()final Optional<Integer>timeoutSeconds()final JsonField<Boolean>_sandbox()Returns the raw JSON value of sandbox. final JsonField<String>_displayName()Returns the raw JSON value of displayName. final JsonField<String>_endpointUrl()Returns the raw JSON value of endpointUrl. final JsonField<WebhookCreateParams.EventFilters>_eventFilters()Returns the raw JSON value of eventFilters. final JsonField<List<String>>_eventTypes()Returns the raw JSON value of eventTypes. final JsonField<Integer>_retryCount()Returns the raw JSON value of retryCount. final JsonField<Integer>_timeoutSeconds()Returns the raw JSON value of timeoutSeconds. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final WebhookCreateParams.BuildertoBuilder()final WebhookCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookCreateParamsnone()final static WebhookCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of WebhookCreateParams. -
-
Method Detail
-
idempotencyKey
final Optional<String> idempotencyKey()
-
xProfileId
final Optional<String> xProfileId()
-
sandbox
final Optional<Boolean> sandbox()
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution
-
displayName
final Optional<String> displayName()
-
endpointUrl
final Optional<String> endpointUrl()
-
eventFilters
final Optional<WebhookCreateParams.EventFilters> eventFilters()
-
eventTypes
final Optional<List<String>> eventTypes()
-
retryCount
final Optional<Integer> retryCount()
-
timeoutSeconds
final Optional<Integer> timeoutSeconds()
-
_sandbox
final JsonField<Boolean> _sandbox()
Returns the raw JSON value of sandbox.
Unlike sandbox, this method doesn't throw if the JSON field has an unexpected type.
-
_displayName
final JsonField<String> _displayName()
Returns the raw JSON value of displayName.
Unlike displayName, this method doesn't throw if the JSON field has an unexpected type.
-
_endpointUrl
final JsonField<String> _endpointUrl()
Returns the raw JSON value of endpointUrl.
Unlike endpointUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_eventFilters
final JsonField<WebhookCreateParams.EventFilters> _eventFilters()
Returns the raw JSON value of eventFilters.
Unlike eventFilters, this method doesn't throw if the JSON field has an unexpected type.
-
_eventTypes
final JsonField<List<String>> _eventTypes()
Returns the raw JSON value of eventTypes.
Unlike eventTypes, this method doesn't throw if the JSON field has an unexpected type.
-
_retryCount
final JsonField<Integer> _retryCount()
Returns the raw JSON value of retryCount.
Unlike retryCount, this method doesn't throw if the JSON field has an unexpected type.
-
_timeoutSeconds
final JsonField<Integer> _timeoutSeconds()
Returns the raw JSON value of timeoutSeconds.
Unlike timeoutSeconds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final WebhookCreateParams.Builder toBuilder()
-
_body
final WebhookCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static WebhookCreateParams none()
-
builder
final static WebhookCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of WebhookCreateParams.
-
-
-
-