Class WebhookCreateResponse
-
- All Implemented Interfaces:
public final class WebhookCreateResponseStandard API response envelope for all v3 endpoints
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookCreateResponse.BuilderA builder for WebhookCreateResponse.
public final classWebhookCreateResponse.DataThe response data (null if error)
public final classWebhookCreateResponse.ErrorError information
public final classWebhookCreateResponse.MetaRequest and response metadata
-
Method Summary
Modifier and Type Method Description final Optional<WebhookCreateResponse.Data>data()The response data (null if error) final Optional<WebhookCreateResponse.Error>error()Error information final Optional<WebhookCreateResponse.Meta>meta()Request and response metadata final Optional<Boolean>success()Indicates whether the request was successful final JsonField<WebhookCreateResponse.Data>_data()Returns the raw JSON value of data. final JsonField<WebhookCreateResponse.Error>_error()Returns the raw JSON value of error. final JsonField<WebhookCreateResponse.Meta>_meta()Returns the raw JSON value of meta. final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final WebhookCreateResponse.BuildertoBuilder()final WebhookCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of WebhookCreateResponse. -
-
Method Detail
-
data
final Optional<WebhookCreateResponse.Data> data()
The response data (null if error)
-
error
final Optional<WebhookCreateResponse.Error> error()
Error information
-
meta
final Optional<WebhookCreateResponse.Meta> meta()
Request and response metadata
-
_data
final JsonField<WebhookCreateResponse.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_error
final JsonField<WebhookCreateResponse.Error> _error()
Returns the raw JSON value of error.
Unlike error, this method doesn't throw if the JSON field has an unexpected type.
-
_meta
final JsonField<WebhookCreateResponse.Meta> _meta()
Returns the raw JSON value of meta.
Unlike meta, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WebhookCreateResponse.Builder toBuilder()
-
validate
final WebhookCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WebhookCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of WebhookCreateResponse.
-
-
-
-