Class WebhookCreateResponse.Data.Builder
-
- All Implemented Interfaces:
public final class WebhookCreateResponse.Data.BuilderA builder for Data.
-
-
Method Summary
-
-
Method Detail
-
id
final WebhookCreateResponse.Data.Builder id(String id)
-
id
final WebhookCreateResponse.Data.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
consecutiveFailures
final WebhookCreateResponse.Data.Builder consecutiveFailures(Integer consecutiveFailures)
-
consecutiveFailures
final WebhookCreateResponse.Data.Builder consecutiveFailures(JsonField<Integer> consecutiveFailures)
Sets Builder.consecutiveFailures to an arbitrary JSON value.
You should usually call Builder.consecutiveFailures with a well-typed Int value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final WebhookCreateResponse.Data.Builder createdAt(OffsetDateTime createdAt)
-
createdAt
final WebhookCreateResponse.Data.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
displayName
final WebhookCreateResponse.Data.Builder displayName(String displayName)
-
displayName
final WebhookCreateResponse.Data.Builder displayName(JsonField<String> displayName)
Sets Builder.displayName to an arbitrary JSON value.
You should usually call Builder.displayName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endpointUrl
final WebhookCreateResponse.Data.Builder endpointUrl(String endpointUrl)
-
endpointUrl
final WebhookCreateResponse.Data.Builder endpointUrl(JsonField<String> endpointUrl)
Sets Builder.endpointUrl to an arbitrary JSON value.
You should usually call Builder.endpointUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventFilters
final WebhookCreateResponse.Data.Builder eventFilters(WebhookCreateResponse.Data.EventFilters eventFilters)
-
eventFilters
final WebhookCreateResponse.Data.Builder eventFilters(Optional<WebhookCreateResponse.Data.EventFilters> eventFilters)
Alias for calling Builder.eventFilters with
eventFilters.orElse(null).
-
eventFilters
final WebhookCreateResponse.Data.Builder eventFilters(JsonField<WebhookCreateResponse.Data.EventFilters> eventFilters)
Sets Builder.eventFilters to an arbitrary JSON value.
You should usually call Builder.eventFilters with a well-typed EventFilters value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventTypes
final WebhookCreateResponse.Data.Builder eventTypes(List<String> eventTypes)
-
eventTypes
final WebhookCreateResponse.Data.Builder eventTypes(JsonField<List<String>> eventTypes)
Sets Builder.eventTypes to an arbitrary JSON value.
You should usually call Builder.eventTypes with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEventType
final WebhookCreateResponse.Data.Builder addEventType(String eventType)
Adds a single String to eventTypes.
-
isActive
final WebhookCreateResponse.Data.Builder isActive(Boolean isActive)
-
isActive
final WebhookCreateResponse.Data.Builder isActive(JsonField<Boolean> isActive)
Sets Builder.isActive to an arbitrary JSON value.
You should usually call Builder.isActive with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastDeliveryAttemptAt
final WebhookCreateResponse.Data.Builder lastDeliveryAttemptAt(OffsetDateTime lastDeliveryAttemptAt)
-
lastDeliveryAttemptAt
final WebhookCreateResponse.Data.Builder lastDeliveryAttemptAt(Optional<OffsetDateTime> lastDeliveryAttemptAt)
Alias for calling Builder.lastDeliveryAttemptAt with
lastDeliveryAttemptAt.orElse(null).
-
lastDeliveryAttemptAt
final WebhookCreateResponse.Data.Builder lastDeliveryAttemptAt(JsonField<OffsetDateTime> lastDeliveryAttemptAt)
Sets Builder.lastDeliveryAttemptAt to an arbitrary JSON value.
You should usually call Builder.lastDeliveryAttemptAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastSuccessfulDeliveryAt
final WebhookCreateResponse.Data.Builder lastSuccessfulDeliveryAt(OffsetDateTime lastSuccessfulDeliveryAt)
-
lastSuccessfulDeliveryAt
final WebhookCreateResponse.Data.Builder lastSuccessfulDeliveryAt(Optional<OffsetDateTime> lastSuccessfulDeliveryAt)
Alias for calling Builder.lastSuccessfulDeliveryAt with
lastSuccessfulDeliveryAt.orElse(null).
-
lastSuccessfulDeliveryAt
final WebhookCreateResponse.Data.Builder lastSuccessfulDeliveryAt(JsonField<OffsetDateTime> lastSuccessfulDeliveryAt)
Sets Builder.lastSuccessfulDeliveryAt to an arbitrary JSON value.
You should usually call Builder.lastSuccessfulDeliveryAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
retryCount
final WebhookCreateResponse.Data.Builder retryCount(Integer retryCount)
-
retryCount
final WebhookCreateResponse.Data.Builder retryCount(JsonField<Integer> retryCount)
Sets Builder.retryCount to an arbitrary JSON value.
You should usually call Builder.retryCount with a well-typed Int value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
signingSecret
final WebhookCreateResponse.Data.Builder signingSecret(String signingSecret)
-
signingSecret
final WebhookCreateResponse.Data.Builder signingSecret(Optional<String> signingSecret)
Alias for calling Builder.signingSecret with
signingSecret.orElse(null).
-
signingSecret
final WebhookCreateResponse.Data.Builder signingSecret(JsonField<String> signingSecret)
Sets Builder.signingSecret to an arbitrary JSON value.
You should usually call Builder.signingSecret with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
timeoutSeconds
final WebhookCreateResponse.Data.Builder timeoutSeconds(Integer timeoutSeconds)
-
timeoutSeconds
final WebhookCreateResponse.Data.Builder timeoutSeconds(JsonField<Integer> timeoutSeconds)
Sets Builder.timeoutSeconds to an arbitrary JSON value.
You should usually call Builder.timeoutSeconds with a well-typed Int value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final WebhookCreateResponse.Data.Builder updatedAt(OffsetDateTime updatedAt)
-
updatedAt
final WebhookCreateResponse.Data.Builder updatedAt(Optional<OffsetDateTime> updatedAt)
Alias for calling Builder.updatedAt with
updatedAt.orElse(null).
-
updatedAt
final WebhookCreateResponse.Data.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WebhookCreateResponse.Data.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WebhookCreateResponse.Data.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WebhookCreateResponse.Data.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WebhookCreateResponse.Data.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WebhookCreateResponse.Data.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WebhookCreateResponse.Data build()
Returns an immutable instance of Data.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-