Class WebhookRetrieveResponse
-
- All Implemented Interfaces:
public final class WebhookRetrieveResponseStandard API response envelope for all v3 endpoints
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookRetrieveResponse.BuilderA builder for WebhookRetrieveResponse.
public final classWebhookRetrieveResponse.DataThe response data (null if error)
public final classWebhookRetrieveResponse.ErrorError information
public final classWebhookRetrieveResponse.MetaRequest and response metadata
-
Method Summary
Modifier and Type Method Description final Optional<WebhookRetrieveResponse.Data>data()The response data (null if error) final Optional<WebhookRetrieveResponse.Error>error()Error information final Optional<WebhookRetrieveResponse.Meta>meta()Request and response metadata final Optional<Boolean>success()Indicates whether the request was successful final JsonField<WebhookRetrieveResponse.Data>_data()Returns the raw JSON value of data. final JsonField<WebhookRetrieveResponse.Error>_error()Returns the raw JSON value of error. final JsonField<WebhookRetrieveResponse.Meta>_meta()Returns the raw JSON value of meta. final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final WebhookRetrieveResponse.BuildertoBuilder()final WebhookRetrieveResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookRetrieveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of WebhookRetrieveResponse. -
-
Method Detail
-
data
final Optional<WebhookRetrieveResponse.Data> data()
The response data (null if error)
-
error
final Optional<WebhookRetrieveResponse.Error> error()
Error information
-
meta
final Optional<WebhookRetrieveResponse.Meta> meta()
Request and response metadata
-
_data
final JsonField<WebhookRetrieveResponse.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_error
final JsonField<WebhookRetrieveResponse.Error> _error()
Returns the raw JSON value of error.
Unlike error, this method doesn't throw if the JSON field has an unexpected type.
-
_meta
final JsonField<WebhookRetrieveResponse.Meta> _meta()
Returns the raw JSON value of meta.
Unlike meta, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WebhookRetrieveResponse.Builder toBuilder()
-
validate
final WebhookRetrieveResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WebhookRetrieveResponse.Builder builder()
Returns a mutable builder for constructing an instance of WebhookRetrieveResponse.
-
-
-
-