Class WebhookRetrieveResponse.Meta
-
- All Implemented Interfaces:
public final class WebhookRetrieveResponse.MetaRequest and response metadata
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookRetrieveResponse.Meta.BuilderA builder for Meta.
-
Method Summary
Modifier and Type Method Description final Optional<String>requestId()Unique identifier for this request (for tracing and support) final Optional<OffsetDateTime>timestamp()Server timestamp when the response was generated final Optional<String>version()API version used for this request final JsonField<String>_requestId()Returns the raw JSON value of requestId. final JsonField<OffsetDateTime>_timestamp()Returns the raw JSON value of timestamp. final JsonField<String>_version()Returns the raw JSON value of version. final Map<String, JsonValue>_additionalProperties()final WebhookRetrieveResponse.Meta.BuildertoBuilder()final WebhookRetrieveResponse.Metavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookRetrieveResponse.Meta.Builderbuilder()Returns a mutable builder for constructing an instance of Meta. -
-
Method Detail
-
requestId
final Optional<String> requestId()
Unique identifier for this request (for tracing and support)
-
timestamp
final Optional<OffsetDateTime> timestamp()
Server timestamp when the response was generated
-
_requestId
final JsonField<String> _requestId()
Returns the raw JSON value of requestId.
Unlike requestId, this method doesn't throw if the JSON field has an unexpected type.
-
_timestamp
final JsonField<OffsetDateTime> _timestamp()
Returns the raw JSON value of timestamp.
Unlike timestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_version
final JsonField<String> _version()
Returns the raw JSON value of version.
Unlike version, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WebhookRetrieveResponse.Meta.Builder toBuilder()
-
validate
final WebhookRetrieveResponse.Meta validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WebhookRetrieveResponse.Meta.Builder builder()
Returns a mutable builder for constructing an instance of Meta.
-
-
-
-