Class WebhookTestResponse
-
- All Implemented Interfaces:
public final class WebhookTestResponseStandard API response envelope for all v3 endpoints
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookTestResponse.BuilderA builder for WebhookTestResponse.
public final classWebhookTestResponse.DataThe response data (null if error)
-
Method Summary
Modifier and Type Method Description final Optional<WebhookTestResponse.Data>data()The response data (null if error) final Optional<ErrorDetail>error()Error information final Optional<ApiMeta>meta()Request and response metadata final Optional<Boolean>success()Indicates whether the request was successful final JsonField<WebhookTestResponse.Data>_data()Returns the raw JSON value of data. final JsonField<ErrorDetail>_error()Returns the raw JSON value of error. final JsonField<ApiMeta>_meta()Returns the raw JSON value of meta. final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final WebhookTestResponse.BuildertoBuilder()final WebhookTestResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookTestResponse.Builderbuilder()Returns a mutable builder for constructing an instance of WebhookTestResponse. -
-
Method Detail
-
data
final Optional<WebhookTestResponse.Data> data()
The response data (null if error)
-
error
final Optional<ErrorDetail> error()
Error information
-
_data
final JsonField<WebhookTestResponse.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_error
final JsonField<ErrorDetail> _error()
Returns the raw JSON value of error.
Unlike error, this method doesn't throw if the JSON field has an unexpected type.
-
_meta
final JsonField<ApiMeta> _meta()
Returns the raw JSON value of meta.
Unlike meta, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WebhookTestResponse.Builder toBuilder()
-
validate
final WebhookTestResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WebhookTestResponse.Builder builder()
Returns a mutable builder for constructing an instance of WebhookTestResponse.
-
-
-
-