Class WebhookTestResponse.Error
-
- All Implemented Interfaces:
public final class WebhookTestResponse.ErrorError information
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookTestResponse.Error.BuilderA builder for Error.
public final classWebhookTestResponse.Error.DetailsAdditional validation error details (field-level errors)
-
Method Summary
Modifier and Type Method Description final Optional<String>code()Machine-readable error code (e.g. final Optional<WebhookTestResponse.Error.Details>details()Additional validation error details (field-level errors) final Optional<String>docUrl()URL to documentation about this error final Optional<String>message()Human-readable error message final JsonField<String>_code()Returns the raw JSON value of code. final JsonField<WebhookTestResponse.Error.Details>_details()Returns the raw JSON value of details. final JsonField<String>_docUrl()Returns the raw JSON value of docUrl. final JsonField<String>_message()Returns the raw JSON value of message. final Map<String, JsonValue>_additionalProperties()final WebhookTestResponse.Error.BuildertoBuilder()final WebhookTestResponse.Errorvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookTestResponse.Error.Builderbuilder()Returns a mutable builder for constructing an instance of Error. -
-
Method Detail
-
details
final Optional<WebhookTestResponse.Error.Details> details()
Additional validation error details (field-level errors)
-
_code
final JsonField<String> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_details
final JsonField<WebhookTestResponse.Error.Details> _details()
Returns the raw JSON value of details.
Unlike details, this method doesn't throw if the JSON field has an unexpected type.
-
_docUrl
final JsonField<String> _docUrl()
Returns the raw JSON value of docUrl.
Unlike docUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WebhookTestResponse.Error.Builder toBuilder()
-
validate
final WebhookTestResponse.Error validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WebhookTestResponse.Error.Builder builder()
Returns a mutable builder for constructing an instance of Error.
-
-
-
-