Class WebhookToggleStatusResponse
-
- All Implemented Interfaces:
public final class WebhookToggleStatusResponseStandard API response envelope for all v3 endpoints
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookToggleStatusResponse.BuilderA builder for WebhookToggleStatusResponse.
public final classWebhookToggleStatusResponse.DataThe response data (null if error)
public final classWebhookToggleStatusResponse.ErrorError information
public final classWebhookToggleStatusResponse.MetaRequest and response metadata
-
Method Summary
Modifier and Type Method Description final Optional<WebhookToggleStatusResponse.Data>data()The response data (null if error) final Optional<WebhookToggleStatusResponse.Error>error()Error information final Optional<WebhookToggleStatusResponse.Meta>meta()Request and response metadata final Optional<Boolean>success()Indicates whether the request was successful final JsonField<WebhookToggleStatusResponse.Data>_data()Returns the raw JSON value of data. final JsonField<WebhookToggleStatusResponse.Error>_error()Returns the raw JSON value of error. final JsonField<WebhookToggleStatusResponse.Meta>_meta()Returns the raw JSON value of meta. final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final WebhookToggleStatusResponse.BuildertoBuilder()final WebhookToggleStatusResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookToggleStatusResponse.Builderbuilder()Returns a mutable builder for constructing an instance of WebhookToggleStatusResponse. -
-
Method Detail
-
data
final Optional<WebhookToggleStatusResponse.Data> data()
The response data (null if error)
-
error
final Optional<WebhookToggleStatusResponse.Error> error()
Error information
-
meta
final Optional<WebhookToggleStatusResponse.Meta> meta()
Request and response metadata
-
_data
final JsonField<WebhookToggleStatusResponse.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_error
final JsonField<WebhookToggleStatusResponse.Error> _error()
Returns the raw JSON value of error.
Unlike error, this method doesn't throw if the JSON field has an unexpected type.
-
_meta
final JsonField<WebhookToggleStatusResponse.Meta> _meta()
Returns the raw JSON value of meta.
Unlike meta, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WebhookToggleStatusResponse.Builder toBuilder()
-
validate
final WebhookToggleStatusResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WebhookToggleStatusResponse.Builder builder()
Returns a mutable builder for constructing an instance of WebhookToggleStatusResponse.
-
-
-
-