Class WebhookToggleStatusResponse.Data
-
- All Implemented Interfaces:
public final class WebhookToggleStatusResponse.DataThe response data (null if error)
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookToggleStatusResponse.Data.BuilderA builder for Data.
public final classWebhookToggleStatusResponse.Data.EventFilters
-
Method Summary
-
-
Method Detail
-
consecutiveFailures
final Optional<Integer> consecutiveFailures()
-
createdAt
final Optional<OffsetDateTime> createdAt()
-
displayName
final Optional<String> displayName()
-
endpointUrl
final Optional<String> endpointUrl()
-
eventFilters
final Optional<WebhookToggleStatusResponse.Data.EventFilters> eventFilters()
-
eventTypes
final Optional<List<String>> eventTypes()
-
lastDeliveryAttemptAt
final Optional<OffsetDateTime> lastDeliveryAttemptAt()
-
lastSuccessfulDeliveryAt
final Optional<OffsetDateTime> lastSuccessfulDeliveryAt()
-
retryCount
final Optional<Integer> retryCount()
-
signingSecret
final Optional<String> signingSecret()
-
timeoutSeconds
final Optional<Integer> timeoutSeconds()
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_consecutiveFailures
final JsonField<Integer> _consecutiveFailures()
Returns the raw JSON value of consecutiveFailures.
Unlike consecutiveFailures, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_displayName
final JsonField<String> _displayName()
Returns the raw JSON value of displayName.
Unlike displayName, this method doesn't throw if the JSON field has an unexpected type.
-
_endpointUrl
final JsonField<String> _endpointUrl()
Returns the raw JSON value of endpointUrl.
Unlike endpointUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_eventFilters
final JsonField<WebhookToggleStatusResponse.Data.EventFilters> _eventFilters()
Returns the raw JSON value of eventFilters.
Unlike eventFilters, this method doesn't throw if the JSON field has an unexpected type.
-
_eventTypes
final JsonField<List<String>> _eventTypes()
Returns the raw JSON value of eventTypes.
Unlike eventTypes, this method doesn't throw if the JSON field has an unexpected type.
-
_isActive
final JsonField<Boolean> _isActive()
Returns the raw JSON value of isActive.
Unlike isActive, this method doesn't throw if the JSON field has an unexpected type.
-
_lastDeliveryAttemptAt
final JsonField<OffsetDateTime> _lastDeliveryAttemptAt()
Returns the raw JSON value of lastDeliveryAttemptAt.
Unlike lastDeliveryAttemptAt, this method doesn't throw if the JSON field has an unexpected type.
-
_lastSuccessfulDeliveryAt
final JsonField<OffsetDateTime> _lastSuccessfulDeliveryAt()
Returns the raw JSON value of lastSuccessfulDeliveryAt.
Unlike lastSuccessfulDeliveryAt, this method doesn't throw if the JSON field has an unexpected type.
-
_retryCount
final JsonField<Integer> _retryCount()
Returns the raw JSON value of retryCount.
Unlike retryCount, this method doesn't throw if the JSON field has an unexpected type.
-
_signingSecret
final JsonField<String> _signingSecret()
Returns the raw JSON value of signingSecret.
Unlike signingSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_timeoutSeconds
final JsonField<Integer> _timeoutSeconds()
Returns the raw JSON value of timeoutSeconds.
Unlike timeoutSeconds, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WebhookToggleStatusResponse.Data.Builder toBuilder()
-
validate
final WebhookToggleStatusResponse.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WebhookToggleStatusResponse.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
-
-
-
-