Class WebhookUpdateResponse
-
- All Implemented Interfaces:
public final class WebhookUpdateResponseStandard API response envelope for all v3 endpoints
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookUpdateResponse.BuilderA builder for WebhookUpdateResponse.
public final classWebhookUpdateResponse.DataThe response data (null if error)
public final classWebhookUpdateResponse.ErrorError information
public final classWebhookUpdateResponse.MetaRequest and response metadata
-
Method Summary
Modifier and Type Method Description final Optional<WebhookUpdateResponse.Data>data()The response data (null if error) final Optional<WebhookUpdateResponse.Error>error()Error information final Optional<WebhookUpdateResponse.Meta>meta()Request and response metadata final Optional<Boolean>success()Indicates whether the request was successful final JsonField<WebhookUpdateResponse.Data>_data()Returns the raw JSON value of data. final JsonField<WebhookUpdateResponse.Error>_error()Returns the raw JSON value of error. final JsonField<WebhookUpdateResponse.Meta>_meta()Returns the raw JSON value of meta. final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final WebhookUpdateResponse.BuildertoBuilder()final WebhookUpdateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookUpdateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of WebhookUpdateResponse. -
-
Method Detail
-
data
final Optional<WebhookUpdateResponse.Data> data()
The response data (null if error)
-
error
final Optional<WebhookUpdateResponse.Error> error()
Error information
-
meta
final Optional<WebhookUpdateResponse.Meta> meta()
Request and response metadata
-
_data
final JsonField<WebhookUpdateResponse.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_error
final JsonField<WebhookUpdateResponse.Error> _error()
Returns the raw JSON value of error.
Unlike error, this method doesn't throw if the JSON field has an unexpected type.
-
_meta
final JsonField<WebhookUpdateResponse.Meta> _meta()
Returns the raw JSON value of meta.
Unlike meta, this method doesn't throw if the JSON field has an unexpected type.
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WebhookUpdateResponse.Builder toBuilder()
-
validate
final WebhookUpdateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WebhookUpdateResponse.Builder builder()
Returns a mutable builder for constructing an instance of WebhookUpdateResponse.
-
-
-
-