Package dm.sent.models.webhooks
Class WebhookUpdateResponse.Error.Details
-
- All Implemented Interfaces:
public final class WebhookUpdateResponse.Error.DetailsAdditional validation error details (field-level errors)
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookUpdateResponse.Error.Details.BuilderA builder for Details.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final WebhookUpdateResponse.Error.Details.BuildertoBuilder()final WebhookUpdateResponse.Error.Detailsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WebhookUpdateResponse.Error.Details.Builderbuilder()Returns a mutable builder for constructing an instance of Details. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WebhookUpdateResponse.Error.Details.Builder toBuilder()
-
validate
final WebhookUpdateResponse.Error.Details validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WebhookUpdateResponse.Error.Details.Builder builder()
Returns a mutable builder for constructing an instance of Details.
-
-
-
-