Package dm.sent.services.async
Class MeServiceAsyncImpl
-
- All Implemented Interfaces:
-
dm.sent.services.async.MeServiceAsync
public final class MeServiceAsyncImpl implements MeServiceAsync
Retrieve account details
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMeServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MeServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MeServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<MeRetrieveResponse>retrieve(MeRetrieveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
MeServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MeServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<MeRetrieveResponse> retrieve(MeRetrieveParams params, RequestOptions requestOptions)
-
-
-
-