Package dm.sent.services.async
Class MessageServiceAsyncImpl
-
- All Implemented Interfaces:
-
dm.sent.services.async.MessageServiceAsync
public final class MessageServiceAsyncImpl implements MessageServiceAsync
Send and track SMS and WhatsApp messages
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMessageServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MessageServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MessageServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<MessageRetrieveActivitiesResponse>retrieveActivities(MessageRetrieveActivitiesParams params, RequestOptions requestOptions)CompletableFuture<MessageRetrieveStatusResponse>retrieveStatus(MessageRetrieveStatusParams params, RequestOptions requestOptions)CompletableFuture<MessageSendResponse>send(MessageSendParams params, RequestOptions requestOptions)-
Methods inherited from class dm.sent.services.async.MessageServiceAsync
retrieveActivities, retrieveActivities, retrieveActivities, retrieveActivities, retrieveActivities, retrieveStatus, retrieveStatus, retrieveStatus, retrieveStatus, retrieveStatus, send, send, send -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
MessageServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MessageServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieveActivities
CompletableFuture<MessageRetrieveActivitiesResponse> retrieveActivities(MessageRetrieveActivitiesParams params, RequestOptions requestOptions)
-
retrieveStatus
CompletableFuture<MessageRetrieveStatusResponse> retrieveStatus(MessageRetrieveStatusParams params, RequestOptions requestOptions)
-
send
CompletableFuture<MessageSendResponse> send(MessageSendParams params, RequestOptions requestOptions)
-
-
-
-