Package dm.sent.services.async
Interface NumberServiceAsync
-
- All Implemented Interfaces:
public interface NumberServiceAsyncManage and lookup phone numbers
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceNumberServiceAsync.WithRawResponseA view of NumberServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract NumberServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract NumberServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<NumberLookupResponse>lookup(String phoneNumber)Retrieves detailed information about a phone number including carrier, line type, porting status, and VoIP detection. CompletableFuture<NumberLookupResponse>lookup(String phoneNumber, NumberLookupParams params, RequestOptions requestOptions)CompletableFuture<NumberLookupResponse>lookup(String phoneNumber, NumberLookupParams params)abstract CompletableFuture<NumberLookupResponse>lookup(NumberLookupParams params, RequestOptions requestOptions)CompletableFuture<NumberLookupResponse>lookup(NumberLookupParams params)CompletableFuture<NumberLookupResponse>lookup(String phoneNumber, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract NumberServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract NumberServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
lookup
CompletableFuture<NumberLookupResponse> lookup(String phoneNumber)
Retrieves detailed information about a phone number including carrier, line type, porting status, and VoIP detection. Uses the customer's messaging provider for rich data, with fallback to the internal index.
-
lookup
CompletableFuture<NumberLookupResponse> lookup(String phoneNumber, NumberLookupParams params, RequestOptions requestOptions)
-
lookup
CompletableFuture<NumberLookupResponse> lookup(String phoneNumber, NumberLookupParams params)
-
lookup
abstract CompletableFuture<NumberLookupResponse> lookup(NumberLookupParams params, RequestOptions requestOptions)
-
lookup
CompletableFuture<NumberLookupResponse> lookup(NumberLookupParams params)
-
lookup
CompletableFuture<NumberLookupResponse> lookup(String phoneNumber, RequestOptions requestOptions)
-
-
-
-