Package dm.sent.services.async
Class NumberServiceAsyncImpl
-
- All Implemented Interfaces:
-
dm.sent.services.async.NumberServiceAsync
public final class NumberServiceAsyncImpl implements NumberServiceAsync
Manage and lookup phone numbers
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classNumberServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description NumberServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. NumberServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<NumberLookupResponse>lookup(NumberLookupParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
NumberServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
NumberServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
lookup
CompletableFuture<NumberLookupResponse> lookup(NumberLookupParams params, RequestOptions requestOptions)
-
-
-
-