Package dm.sent.services.async
Class NumberServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dm.sent.services.async.NumberServiceAsync.WithRawResponse
public final class NumberServiceAsyncImpl.WithRawResponseImpl implements NumberServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description NumberServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<NumberLookupResponse>>lookup(NumberLookupParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
NumberServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
lookup
CompletableFuture<HttpResponseFor<NumberLookupResponse>> lookup(NumberLookupParams params, RequestOptions requestOptions)
-
-
-
-