Package dm.sent.services.async
Class ProfileServiceAsyncImpl
-
- All Implemented Interfaces:
-
dm.sent.services.async.ProfileServiceAsync
public final class ProfileServiceAsyncImpl implements ProfileServiceAsync
Manage organization profiles
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProfileServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dm.sent.services.async.ProfileServiceAsync
complete, complete, complete, create, create, create, delete, delete, delete, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ProfileServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ProfileServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
campaigns
CampaignServiceAsync campaigns()
Manage organization profiles
-
create
CompletableFuture<ApiResponseOfProfileDetail> create(ProfileCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<ApiResponseOfProfileDetail> retrieve(ProfileRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<ApiResponseOfProfileDetail> update(ProfileUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ProfileListResponse> list(ProfileListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(ProfileDeleteParams params, RequestOptions requestOptions)
-
complete
CompletableFuture<ProfileCompleteResponse> complete(ProfileCompleteParams params, RequestOptions requestOptions)
-
-
-
-