Package dm.sent.services.async
Class UserServiceAsyncImpl
-
- All Implemented Interfaces:
-
dm.sent.services.async.UserServiceAsync
public final class UserServiceAsyncImpl implements UserServiceAsync
Invite, update, and manage organization users and roles
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUserServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description UserServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. UserServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<ApiResponseOfUser>retrieve(UserRetrieveParams params, RequestOptions requestOptions)CompletableFuture<UserListResponse>list(UserListParams params, RequestOptions requestOptions)CompletableFuture<ApiResponseOfUser>invite(UserInviteParams params, RequestOptions requestOptions)CompletableFuture<Void>remove(UserRemoveParams params, RequestOptions requestOptions)CompletableFuture<ApiResponseOfUser>updateRole(UserUpdateRoleParams params, RequestOptions requestOptions)-
Methods inherited from class dm.sent.services.async.UserServiceAsync
invite, invite, invite, list, list, list, remove, remove, remove, retrieve, retrieve, retrieve, retrieve, retrieve, updateRole, updateRole, updateRole, updateRole, updateRole -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
UserServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
UserServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<ApiResponseOfUser> retrieve(UserRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<UserListResponse> list(UserListParams params, RequestOptions requestOptions)
-
invite
CompletableFuture<ApiResponseOfUser> invite(UserInviteParams params, RequestOptions requestOptions)
-
remove
CompletableFuture<Void> remove(UserRemoveParams params, RequestOptions requestOptions)
-
updateRole
CompletableFuture<ApiResponseOfUser> updateRole(UserUpdateRoleParams params, RequestOptions requestOptions)
-
-
-
-