Interface WebhookServiceAsync
-
- All Implemented Interfaces:
public interface WebhookServiceAsyncConfigure webhook endpoints for real-time event delivery
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWebhookServiceAsync.WithRawResponseA view of WebhookServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract WebhookServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract WebhookServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<ApiResponseWebhook> create()
Creates a new webhook endpoint for the authenticated customer.
-
create
abstract CompletableFuture<ApiResponseWebhook> create(WebhookCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<ApiResponseWebhook> create(WebhookCreateParams params)
-
create
CompletableFuture<ApiResponseWebhook> create(RequestOptions requestOptions)
-
retrieve
CompletableFuture<ApiResponseWebhook> retrieve(String id)
Retrieves a single webhook by ID for the authenticated customer.
-
retrieve
CompletableFuture<ApiResponseWebhook> retrieve(String id, WebhookRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<ApiResponseWebhook> retrieve(String id, WebhookRetrieveParams params)
-
retrieve
abstract CompletableFuture<ApiResponseWebhook> retrieve(WebhookRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<ApiResponseWebhook> retrieve(WebhookRetrieveParams params)
-
retrieve
CompletableFuture<ApiResponseWebhook> retrieve(String id, RequestOptions requestOptions)
-
update
CompletableFuture<ApiResponseWebhook> update(String id)
Updates an existing webhook for the authenticated customer.
-
update
CompletableFuture<ApiResponseWebhook> update(String id, WebhookUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<ApiResponseWebhook> update(String id, WebhookUpdateParams params)
-
update
abstract CompletableFuture<ApiResponseWebhook> update(WebhookUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<ApiResponseWebhook> update(WebhookUpdateParams params)
-
update
CompletableFuture<ApiResponseWebhook> update(String id, RequestOptions requestOptions)
-
list
CompletableFuture<WebhookListResponse> list(WebhookListParams params)
Retrieves a paginated list of webhooks for the authenticated customer.
-
list
abstract CompletableFuture<WebhookListResponse> list(WebhookListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String id)
Deletes a webhook for the authenticated customer.
-
delete
CompletableFuture<Void> delete(String id, WebhookDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String id, WebhookDeleteParams params)
-
delete
abstract CompletableFuture<Void> delete(WebhookDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(WebhookDeleteParams params)
-
delete
CompletableFuture<Void> delete(String id, RequestOptions requestOptions)
-
listEventTypes
CompletableFuture<WebhookListEventTypesResponse> listEventTypes()
Retrieves all available webhook event types that can be subscribed to.
-
listEventTypes
abstract CompletableFuture<WebhookListEventTypesResponse> listEventTypes(WebhookListEventTypesParams params, RequestOptions requestOptions)
-
listEventTypes
CompletableFuture<WebhookListEventTypesResponse> listEventTypes(WebhookListEventTypesParams params)
-
listEventTypes
CompletableFuture<WebhookListEventTypesResponse> listEventTypes(RequestOptions requestOptions)
-
listEvents
CompletableFuture<WebhookListEventsResponse> listEvents(String id, WebhookListEventsParams params)
Retrieves a paginated list of delivery events for the specified webhook.
-
listEvents
CompletableFuture<WebhookListEventsResponse> listEvents(String id, WebhookListEventsParams params, RequestOptions requestOptions)
-
listEvents
CompletableFuture<WebhookListEventsResponse> listEvents(WebhookListEventsParams params)
-
listEvents
abstract CompletableFuture<WebhookListEventsResponse> listEvents(WebhookListEventsParams params, RequestOptions requestOptions)
-
rotateSecret
CompletableFuture<WebhookRotateSecretResponse> rotateSecret(String id)
Generates a new signing secret for the specified webhook. The old secret is immediately invalidated.
-
rotateSecret
CompletableFuture<WebhookRotateSecretResponse> rotateSecret(String id, WebhookRotateSecretParams params, RequestOptions requestOptions)
-
rotateSecret
CompletableFuture<WebhookRotateSecretResponse> rotateSecret(String id, WebhookRotateSecretParams params)
-
rotateSecret
abstract CompletableFuture<WebhookRotateSecretResponse> rotateSecret(WebhookRotateSecretParams params, RequestOptions requestOptions)
-
rotateSecret
CompletableFuture<WebhookRotateSecretResponse> rotateSecret(WebhookRotateSecretParams params)
-
rotateSecret
CompletableFuture<WebhookRotateSecretResponse> rotateSecret(String id, RequestOptions requestOptions)
-
test
CompletableFuture<WebhookTestResponse> test(String id)
Sends a test event to the specified webhook endpoint to verify connectivity.
-
test
CompletableFuture<WebhookTestResponse> test(String id, WebhookTestParams params, RequestOptions requestOptions)
-
test
CompletableFuture<WebhookTestResponse> test(String id, WebhookTestParams params)
-
test
abstract CompletableFuture<WebhookTestResponse> test(WebhookTestParams params, RequestOptions requestOptions)
-
test
CompletableFuture<WebhookTestResponse> test(WebhookTestParams params)
-
test
CompletableFuture<WebhookTestResponse> test(String id, RequestOptions requestOptions)
-
toggleStatus
CompletableFuture<ApiResponseWebhook> toggleStatus(String id)
Activates or deactivates a webhook for the authenticated customer.
-
toggleStatus
CompletableFuture<ApiResponseWebhook> toggleStatus(String id, WebhookToggleStatusParams params, RequestOptions requestOptions)
-
toggleStatus
CompletableFuture<ApiResponseWebhook> toggleStatus(String id, WebhookToggleStatusParams params)
-
toggleStatus
abstract CompletableFuture<ApiResponseWebhook> toggleStatus(WebhookToggleStatusParams params, RequestOptions requestOptions)
-
toggleStatus
CompletableFuture<ApiResponseWebhook> toggleStatus(WebhookToggleStatusParams params)
-
toggleStatus
CompletableFuture<ApiResponseWebhook> toggleStatus(String id, RequestOptions requestOptions)
-
-
-
-