Package dm.sent.services.async
Class WebhookServiceAsyncImpl
-
- All Implemented Interfaces:
-
dm.sent.services.async.WebhookServiceAsync
public final class WebhookServiceAsyncImpl implements WebhookServiceAsync
Configure webhook endpoints for real-time event delivery
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dm.sent.services.async.WebhookServiceAsync
create, create, create, delete, delete, delete, delete, delete, list, listEventTypes, listEventTypes, listEventTypes, listEvents, listEvents, listEvents, retrieve, retrieve, retrieve, retrieve, retrieve, rotateSecret, rotateSecret, rotateSecret, test, test, test, test, test, toggleStatus, toggleStatus, toggleStatus, toggleStatus, toggleStatus, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
WebhookServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
WebhookServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<ApiResponseWebhook> create(WebhookCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<ApiResponseWebhook> retrieve(WebhookRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<ApiResponseWebhook> update(WebhookUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<WebhookListResponse> list(WebhookListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(WebhookDeleteParams params, RequestOptions requestOptions)
-
listEventTypes
CompletableFuture<WebhookListEventTypesResponse> listEventTypes(WebhookListEventTypesParams params, RequestOptions requestOptions)
-
listEvents
CompletableFuture<WebhookListEventsResponse> listEvents(WebhookListEventsParams params, RequestOptions requestOptions)
-
rotateSecret
CompletableFuture<WebhookRotateSecretResponse> rotateSecret(WebhookRotateSecretParams params, RequestOptions requestOptions)
-
test
CompletableFuture<WebhookTestResponse> test(WebhookTestParams params, RequestOptions requestOptions)
-
toggleStatus
CompletableFuture<ApiResponseWebhook> toggleStatus(WebhookToggleStatusParams params, RequestOptions requestOptions)
-
-
-
-