Package dm.sent.services.async
Class WebhookServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
dm.sent.services.async.WebhookServiceAsync.WithRawResponse
public final class WebhookServiceAsyncImpl.WithRawResponseImpl implements WebhookServiceAsync.WithRawResponse
-
-
Method Summary
-
Methods inherited from class dm.sent.services.async.WebhookServiceAsync.WithRawResponse
create, create, create, delete, delete, delete, delete, delete, list, listEventTypes, listEventTypes, listEventTypes, listEvents, listEvents, listEvents, retrieve, retrieve, retrieve, retrieve, retrieve, rotateSecret, rotateSecret, rotateSecret, test, test, test, test, test, toggleStatus, toggleStatus, toggleStatus, toggleStatus, toggleStatus, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
WebhookServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<ApiResponseWebhook>> create(WebhookCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<ApiResponseWebhook>> retrieve(WebhookRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<ApiResponseWebhook>> update(WebhookUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<WebhookListResponse>> list(WebhookListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponse> delete(WebhookDeleteParams params, RequestOptions requestOptions)
-
listEventTypes
CompletableFuture<HttpResponseFor<WebhookListEventTypesResponse>> listEventTypes(WebhookListEventTypesParams params, RequestOptions requestOptions)
-
listEvents
CompletableFuture<HttpResponseFor<WebhookListEventsResponse>> listEvents(WebhookListEventsParams params, RequestOptions requestOptions)
-
rotateSecret
CompletableFuture<HttpResponseFor<WebhookRotateSecretResponse>> rotateSecret(WebhookRotateSecretParams params, RequestOptions requestOptions)
-
test
CompletableFuture<HttpResponseFor<WebhookTestResponse>> test(WebhookTestParams params, RequestOptions requestOptions)
-
toggleStatus
CompletableFuture<HttpResponseFor<ApiResponseWebhook>> toggleStatus(WebhookToggleStatusParams params, RequestOptions requestOptions)
-
-
-
-