Package dm.sent.services.blocking
Class MeServiceImpl
-
- All Implemented Interfaces:
-
dm.sent.services.blocking.MeService
public final class MeServiceImpl implements MeService
Retrieve account details
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMeServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MeService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MeServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. MeRetrieveResponseretrieve(MeRetrieveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
MeService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MeService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
MeRetrieveResponse retrieve(MeRetrieveParams params, RequestOptions requestOptions)
-
-
-
-