Package dm.sent.services.blocking
Class UserServiceImpl
-
- All Implemented Interfaces:
-
dm.sent.services.blocking.UserService
public final class UserServiceImpl implements UserService
Invite, update, and manage organization users and roles
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUserServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description UserService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. UserServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ApiResponseOfUserretrieve(UserRetrieveParams params, RequestOptions requestOptions)UserListResponselist(UserListParams params, RequestOptions requestOptions)ApiResponseOfUserinvite(UserInviteParams params, RequestOptions requestOptions)Unitremove(UserRemoveParams params, RequestOptions requestOptions)ApiResponseOfUserupdateRole(UserUpdateRoleParams params, RequestOptions requestOptions)-
Methods inherited from class dm.sent.services.blocking.UserService
invite, invite, invite, list, list, list, remove, remove, remove, retrieve, retrieve, retrieve, retrieve, retrieve, updateRole, updateRole, updateRole, updateRole, updateRole -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
UserService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
UserService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
ApiResponseOfUser retrieve(UserRetrieveParams params, RequestOptions requestOptions)
-
list
UserListResponse list(UserListParams params, RequestOptions requestOptions)
-
invite
ApiResponseOfUser invite(UserInviteParams params, RequestOptions requestOptions)
-
remove
Unit remove(UserRemoveParams params, RequestOptions requestOptions)
-
updateRole
ApiResponseOfUser updateRole(UserUpdateRoleParams params, RequestOptions requestOptions)
-
-
-
-