Package dm.sent.services.blocking
Class WebhookServiceImpl
-
- All Implemented Interfaces:
-
dm.sent.services.blocking.WebhookService
public final class WebhookServiceImpl implements WebhookService
Configure webhook endpoints for real-time event delivery
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookServiceImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class dm.sent.services.blocking.WebhookService
create, create, create, delete, delete, delete, delete, delete, list, listEventTypes, listEventTypes, listEventTypes, listEvents, listEvents, listEvents, retrieve, retrieve, retrieve, retrieve, retrieve, rotateSecret, rotateSecret, rotateSecret, test, test, test, test, test, toggleStatus, toggleStatus, toggleStatus, toggleStatus, toggleStatus, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
WebhookService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
WebhookService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
ApiResponseWebhook create(WebhookCreateParams params, RequestOptions requestOptions)
-
retrieve
ApiResponseWebhook retrieve(WebhookRetrieveParams params, RequestOptions requestOptions)
-
update
ApiResponseWebhook update(WebhookUpdateParams params, RequestOptions requestOptions)
-
list
WebhookListResponse list(WebhookListParams params, RequestOptions requestOptions)
-
delete
Unit delete(WebhookDeleteParams params, RequestOptions requestOptions)
-
listEventTypes
WebhookListEventTypesResponse listEventTypes(WebhookListEventTypesParams params, RequestOptions requestOptions)
-
listEvents
WebhookListEventsResponse listEvents(WebhookListEventsParams params, RequestOptions requestOptions)
-
rotateSecret
WebhookRotateSecretResponse rotateSecret(WebhookRotateSecretParams params, RequestOptions requestOptions)
-
test
WebhookTestResponse test(WebhookTestParams params, RequestOptions requestOptions)
-
toggleStatus
ApiResponseWebhook toggleStatus(WebhookToggleStatusParams params, RequestOptions requestOptions)
-
-
-
-