Class WebhookCreateParams.Body
-
- All Implemented Interfaces:
public final class WebhookCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookCreateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
toMutationRequest
final MutationRequest toMutationRequest()
-
sandbox
final Optional<Boolean> sandbox()
Sandbox flag - when true, the operation is simulated without side effects Useful for testing integrations without actual execution
-
displayName
final Optional<String> displayName()
-
endpointUrl
final Optional<String> endpointUrl()
-
eventFilters
final Optional<WebhookCreateParams.EventFilters> eventFilters()
-
eventTypes
final Optional<List<String>> eventTypes()
-
retryCount
final Optional<Integer> retryCount()
-
timeoutSeconds
final Optional<Integer> timeoutSeconds()
-
_sandbox
final JsonField<Boolean> _sandbox()
Returns the raw JSON value of sandbox.
Unlike sandbox, this method doesn't throw if the JSON field has an unexpected type.
-
_displayName
final JsonField<String> _displayName()
Returns the raw JSON value of displayName.
Unlike displayName, this method doesn't throw if the JSON field has an unexpected type.
-
_endpointUrl
final JsonField<String> _endpointUrl()
Returns the raw JSON value of endpointUrl.
Unlike endpointUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_eventFilters
final JsonField<WebhookCreateParams.EventFilters> _eventFilters()
Returns the raw JSON value of eventFilters.
Unlike eventFilters, this method doesn't throw if the JSON field has an unexpected type.
-
_eventTypes
final JsonField<List<String>> _eventTypes()
Returns the raw JSON value of eventTypes.
Unlike eventTypes, this method doesn't throw if the JSON field has an unexpected type.
-
_retryCount
final JsonField<Integer> _retryCount()
Returns the raw JSON value of retryCount.
Unlike retryCount, this method doesn't throw if the JSON field has an unexpected type.
-
_timeoutSeconds
final JsonField<Integer> _timeoutSeconds()
Returns the raw JSON value of timeoutSeconds.
Unlike timeoutSeconds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WebhookCreateParams.Body.Builder toBuilder()
-
validate
final WebhookCreateParams.Body validate()
-
builder
final static WebhookCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-